==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkResliceCursorRepresentation.java <==
// java wrapper for vtkResliceCursorRepresentation object
//

package vtk;
import vtk.*;

public class vtkResliceCursorRepresentation extends vtkWidgetRepresentation
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetTolerance_2(int id0);
  public void SetTolerance(int id0)
    { SetTolerance_2(id0); }

  private native int GetToleranceMinValue_3();
  public int GetToleranceMinValue()
    { return GetToleranceMinValue_3(); }

  private native int GetToleranceMaxValue_4();
  public int GetToleranceMaxValue()
    { return GetToleranceMaxValue_4(); }

  private native int GetTolerance_5();
  public int GetTolerance()
    { return GetTolerance_5(); }

  private native void SetShowReslicedImage_6(int id0);
  public void SetShowReslicedImage(int id0)
    { SetShowReslicedImage_6(id0); }

  private native int GetShowReslicedImage_7();
  public int GetShowReslicedImage()
    { return GetShowReslicedImage_7(); }

  private native void ShowReslicedImageOn_8();
  public void ShowReslicedImageOn()
    { ShowReslicedImageOn_8(); }

  private native void ShowReslicedImageOff_9();
  public void ShowReslicedImageOff()
    { ShowReslicedImageOff_9(); }

  private native void SetRestrictPlaneToVolume_10(int id0);
  public void SetRestrictPlaneToVolume(int id0)
    { SetRestrictPlaneToVolume_10(id0); }

  private native int GetRestrictPlaneToVolume_11();
  public int GetRestrictPlaneToVolume()
    { return GetRestrictPlaneToVolume_11(); }

  private native void RestrictPlaneToVolumeOn_12();
  public void RestrictPlaneToVolumeOn()
    { RestrictPlaneToVolumeOn_12(); }

  private native void RestrictPlaneToVolumeOff_13();
  public void RestrictPlaneToVolumeOff()
    { RestrictPlaneToVolumeOff_13(); }

  private native void SetThicknessLabelFormat_14(String id0);
  public void SetThicknessLabelFormat(String id0)
    { SetThicknessLabelFormat_14(id0); }

  private native String GetThicknessLabelFormat_15();
  public String GetThicknessLabelFormat()
    { return GetThicknessLabelFormat_15(); }

  private native String GetThicknessLabelText_16();
  public String GetThicknessLabelText()
    { return GetThicknessLabelText_16(); }

  private native void GetThicknessLabelPosition_17(double id0[]);
  public void GetThicknessLabelPosition(double id0[])
    { GetThicknessLabelPosition_17(id0); }

  private native void GetWorldThicknessLabelPosition_18(double id0[]);
  public void GetWorldThicknessLabelPosition(double id0[])
    { GetWorldThicknessLabelPosition_18(id0); }

  private native void BuildRepresentation_19();
  public void BuildRepresentation()
    { BuildRepresentation_19(); }

  private native long GetResliceAxes_20();
  public vtkMatrix4x4 GetResliceAxes() {
    long temp = GetResliceAxes_20();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetReslice_21();
  public vtkImageAlgorithm GetReslice() {
    long temp = GetReslice_21();

    if (temp == 0) return null;
    return (vtkImageAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetImageActor_22();
  public vtkImageActor GetImageActor() {
    long temp = GetImageActor_22();

    if (temp == 0) return null;
    return (vtkImageActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLookupTable_23(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_23(id0); }

  private native long GetLookupTable_24();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_24();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetColorMap_25();
  public vtkImageMapToColors GetColorMap() {
    long temp = GetColorMap_25();

    if (temp == 0) return null;
    return (vtkImageMapToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetColorMap_26(vtkImageMapToColors id0);
  public void SetColorMap(vtkImageMapToColors id0)
    { SetColorMap_26(id0); }

  private native void SetWindowLevel_27(double id0,double id1,int id2);
  public void SetWindowLevel(double id0,double id1,int id2)
    { SetWindowLevel_27(id0,id1,id2); }

  private native void GetWindowLevel_28(double id0[]);
  public void GetWindowLevel(double id0[])
    { GetWindowLevel_28(id0); }

  private native double GetWindow_29();
  public double GetWindow()
    { return GetWindow_29(); }

  private native double GetLevel_30();
  public double GetLevel()
    { return GetLevel_30(); }

  private native long GetResliceCursor_31();
  public vtkResliceCursor GetResliceCursor() {
    long temp = GetResliceCursor_31();

    if (temp == 0) return null;
    return (vtkResliceCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDisplayText_32(int id0);
  public void SetDisplayText(int id0)
    { SetDisplayText_32(id0); }

  private native int GetDisplayText_33();
  public int GetDisplayText()
    { return GetDisplayText_33(); }

  private native void DisplayTextOn_34();
  public void DisplayTextOn()
    { DisplayTextOn_34(); }

  private native void DisplayTextOff_35();
  public void DisplayTextOff()
    { DisplayTextOff_35(); }

  private native void SetTextProperty_36(vtkTextProperty id0);
  public void SetTextProperty(vtkTextProperty id0)
    { SetTextProperty_36(id0); }

  private native long GetTextProperty_37();
  public vtkTextProperty GetTextProperty() {
    long temp = GetTextProperty_37();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUseImageActor_38(int id0);
  public void SetUseImageActor(int id0)
    { SetUseImageActor_38(id0); }

  private native int GetUseImageActor_39();
  public int GetUseImageActor()
    { return GetUseImageActor_39(); }

  private native void UseImageActorOn_40();
  public void UseImageActorOn()
    { UseImageActorOn_40(); }

  private native void UseImageActorOff_41();
  public void UseImageActorOff()
    { UseImageActorOff_41(); }

  private native void SetManipulationMode_42(int id0);
  public void SetManipulationMode(int id0)
    { SetManipulationMode_42(id0); }

  private native int GetManipulationMode_43();
  public int GetManipulationMode()
    { return GetManipulationMode_43(); }

  private native void ActivateText_44(int id0);
  public void ActivateText(int id0)
    { ActivateText_44(id0); }

  private native void ManageTextDisplay_45();
  public void ManageTextDisplay()
    { ManageTextDisplay_45(); }

  private native void InitializeReslicePlane_46();
  public void InitializeReslicePlane()
    { InitializeReslicePlane_46(); }

  private native void ResetCamera_47();
  public void ResetCamera()
    { ResetCamera_47(); }

  private native long GetCursorAlgorithm_48();
  public vtkResliceCursorPolyDataAlgorithm GetCursorAlgorithm() {
    long temp = GetCursorAlgorithm_48();

    if (temp == 0) return null;
    return (vtkResliceCursorPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPlaneSource_49();
  public vtkPlaneSource GetPlaneSource() {
    long temp = GetPlaneSource_49();

    if (temp == 0) return null;
    return (vtkPlaneSource)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkResliceCursorRepresentation() { super(); }

  public vtkResliceCursorRepresentation(long id) { super(id); }

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkResliceCursorRepresentation.java <==
// java wrapper for vtkResliceCursorRepresentation object
//

package vtk;
import vtk.*;

public class vtkResliceCursorRepresentation extends vtkWidgetRepresentation
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetTolerance_2(int id0);
  public void SetTolerance(int id0)
    { SetTolerance_2(id0); }

  private native int GetToleranceMinValue_3();
  public int GetToleranceMinValue()
    { return GetToleranceMinValue_3(); }

  private native int GetToleranceMaxValue_4();
  public int GetToleranceMaxValue()
    { return GetToleranceMaxValue_4(); }

  private native int GetTolerance_5();
  public int GetTolerance()
    { return GetTolerance_5(); }

  private native void SetShowReslicedImage_6(int id0);
  public void SetShowReslicedImage(int id0)
    { SetShowReslicedImage_6(id0); }

  private native int GetShowReslicedImage_7();
  public int GetShowReslicedImage()
    { return GetShowReslicedImage_7(); }

  private native void ShowReslicedImageOn_8();
  public void ShowReslicedImageOn()
    { ShowReslicedImageOn_8(); }

  private native void ShowReslicedImageOff_9();
  public void ShowReslicedImageOff()
    { ShowReslicedImageOff_9(); }

  private native void SetRestrictPlaneToVolume_10(int id0);
  public void SetRestrictPlaneToVolume(int id0)
    { SetRestrictPlaneToVolume_10(id0); }

  private native int GetRestrictPlaneToVolume_11();
  public int GetRestrictPlaneToVolume()
    { return GetRestrictPlaneToVolume_11(); }

  private native void RestrictPlaneToVolumeOn_12();
  public void RestrictPlaneToVolumeOn()
    { RestrictPlaneToVolumeOn_12(); }

  private native void RestrictPlaneToVolumeOff_13();
  public void RestrictPlaneToVolumeOff()
    { RestrictPlaneToVolumeOff_13(); }

  private native void SetThicknessLabelFormat_14(String id0);
  public void SetThicknessLabelFormat(String id0)
    { SetThicknessLabelFormat_14(id0); }

  private native String GetThicknessLabelFormat_15();
  public String GetThicknessLabelFormat()
    { return GetThicknessLabelFormat_15(); }

  private native String GetThicknessLabelText_16();
  public String GetThicknessLabelText()
    { return GetThicknessLabelText_16(); }

  private native void GetThicknessLabelPosition_17(double id0[]);
  public void GetThicknessLabelPosition(double id0[])
    { GetThicknessLabelPosition_17(id0); }

  private native void GetWorldThicknessLabelPosition_18(double id0[]);
  public void GetWorldThicknessLabelPosition(double id0[])
    { GetWorldThicknessLabelPosition_18(id0); }

  private native void BuildRepresentation_19();
  public void BuildRepresentation()
    { BuildRepresentation_19(); }

  private native long GetResliceAxes_20();
  public vtkMatrix4x4 GetResliceAxes() {
    long temp = GetResliceAxes_20();

    if (temp == 0) return null;
    return (vtkMatrix4x4)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetReslice_21();
  public vtkImageAlgorithm GetReslice() {
    long temp = GetReslice_21();

    if (temp == 0) return null;
    return (vtkImageAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetImageActor_22();
  public vtkImageActor GetImageActor() {
    long temp = GetImageActor_22();

    if (temp == 0) return null;
    return (vtkImageActor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLookupTable_23(vtkScalarsToColors id0);
  public void SetLookupTable(vtkScalarsToColors id0)
    { SetLookupTable_23(id0); }

  private native long GetLookupTable_24();
  public vtkScalarsToColors GetLookupTable() {
    long temp = GetLookupTable_24();

    if (temp == 0) return null;
    return (vtkScalarsToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetColorMap_25();
  public vtkImageMapToColors GetColorMap() {
    long temp = GetColorMap_25();

    if (temp == 0) return null;
    return (vtkImageMapToColors)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetColorMap_26(vtkImageMapToColors id0);
  public void SetColorMap(vtkImageMapToColors id0)
    { SetColorMap_26(id0); }

  private native void SetWindowLevel_27(double id0,double id1,int id2);
  public void SetWindowLevel(double id0,double id1,int id2)
    { SetWindowLevel_27(id0,id1,id2); }

  private native void GetWindowLevel_28(double id0[]);
  public void GetWindowLevel(double id0[])
    { GetWindowLevel_28(id0); }

  private native double GetWindow_29();
  public double GetWindow()
    { return GetWindow_29(); }

  private native double GetLevel_30();
  public double GetLevel()
    { return GetLevel_30(); }

  private native long GetResliceCursor_31();
  public vtkResliceCursor GetResliceCursor() {
    long temp = GetResliceCursor_31();

    if (temp == 0) return null;
    return (vtkResliceCursor)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDisplayText_32(int id0);
  public void SetDisplayText(int id0)
    { SetDisplayText_32(id0); }

  private native int GetDisplayText_33();
  public int GetDisplayText()
    { return GetDisplayText_33(); }

  private native void DisplayTextOn_34();
  public void DisplayTextOn()
    { DisplayTextOn_34(); }

  private native void DisplayTextOff_35();
  public void DisplayTextOff()
    { DisplayTextOff_35(); }

  private native void SetTextProperty_36(vtkTextProperty id0);
  public void SetTextProperty(vtkTextProperty id0)
    { SetTextProperty_36(id0); }

  private native long GetTextProperty_37();
  public vtkTextProperty GetTextProperty() {
    long temp = GetTextProperty_37();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetUseImageActor_38(int id0);
  public void SetUseImageActor(int id0)
    { SetUseImageActor_38(id0); }

  private native int GetUseImageActor_39();
  public int GetUseImageActor()
    { return GetUseImageActor_39(); }

  private native void UseImageActorOn_40();
  public void UseImageActorOn()
    { UseImageActorOn_40(); }

  private native void UseImageActorOff_41();
  public void UseImageActorOff()
    { UseImageActorOff_41(); }

  private native void SetManipulationMode_42(int id0);
  public void SetManipulationMode(int id0)
    { SetManipulationMode_42(id0); }

  private native int GetManipulationMode_43();
  public int GetManipulationMode()
    { return GetManipulationMode_43(); }

  private native void ActivateText_44(int id0);
  public void ActivateText(int id0)
    { ActivateText_44(id0); }

  private native void ManageTextDisplay_45();
  public void ManageTextDisplay()
    { ManageTextDisplay_45(); }

  private native void InitializeReslicePlane_46();
  public void InitializeReslicePlane()
    { InitializeReslicePlane_46(); }

  private native void ResetCamera_47();
  public void ResetCamera()
    { ResetCamera_47(); }

  private native long GetCursorAlgorithm_48();
  public vtkResliceCursorPolyDataAlgorithm GetCursorAlgorithm() {
    long temp = GetCursorAlgorithm_48();

    if (temp == 0) return null;
    return (vtkResliceCursorPolyDataAlgorithm)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPlaneSource_49();
  public vtkPlaneSource GetPlaneSource() {
    long temp = GetPlaneSource_49();

    if (temp == 0) return null;
    return (vtkPlaneSource)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkResliceCursorRepresentation() { super(); }

  public vtkResliceCursorRepresentation(long id) { super(id); }

}
